==> blesta-5.10.2.zip: blesta/components/gateways/nonmerchant/paypal_payments_standard/language/en_us/paypal_payments_standard.php <==
<?php
$lang['PaypalPaymentsStandard.name'] = 'PayPal Payments Standard';
$lang['PaypalPaymentsStandard.description'] = 'PayPal Payments Standard is one of the easiest ways to securely accept credit card and PayPal payments online';

$lang['PaypalPaymentsStandard.account_id'] = 'PayPal Account Email';
$lang['PaypalPaymentsStandard.page_style'] = 'Page Style Name';
$lang['PaypalPaymentsStandard.page_style_note'] = 'The Page Style Name of the custom payment page theme you created in PayPal. Leave blank for the default page style.';
$lang['PaypalPaymentsStandard.dev_mode'] = 'Developer Mode';
$lang['PaypalPaymentsStandard.dev_mode_note'] = 'Enabling this option will post transactions to the PayPal Sandbox environment. Only enable this option if you are testing with a PayPal Sandbox account.';
$lang['PaypalPaymentsStandard.api_username'] = 'API Username';
$lang['PaypalPaymentsStandard.api_username_note'] = 'This, as well as API Password and API Signature, are required in order to process refunds through PayPal.';
$lang['PaypalPaymentsStandard.api_password'] = 'API Password';
$lang['PaypalPaymentsStandard.api_signature'] = 'API Signature';
$lang['PaypalPaymentsStandard.pay_type'] = 'Payment Options';
$lang['PaypalPaymentsStandard.pay_type_onetime'] = 'One time payments only';
$lang['PaypalPaymentsStandard.pay_type_subscribe'] = 'Subscription payments only';
$lang['PaypalPaymentsStandard.pay_type_both'] = 'One time and subscription payments when possible';

$lang['PaypalPaymentsStandard.buildprocess.submit'] = 'Pay with PayPal';

// Errors
$lang['PaypalPaymentsStandard.!error.account_id.valid'] = 'You must enter a valid email address.';
$lang['PaypalPaymentsStandard.!error.dev_mode.valid'] = 'Developer mode must be set to "true" if given.';

==> blesta-5.11.4.zip: blesta/components/gateways/nonmerchant/paypal_payments_standard/language/en_us/paypal_payments_standard.php <==
<?php
$lang['PaypalPaymentsStandard.name'] = 'PayPal Payments Standard';
$lang['PaypalPaymentsStandard.description'] = 'PayPal Payments Standard is one of the easiest ways to securely accept credit card and PayPal payments online';

$lang['PaypalPaymentsStandard.account_id'] = 'PayPal Account Email';
$lang['PaypalPaymentsStandard.page_style'] = 'Page Style Name';
$lang['PaypalPaymentsStandard.page_style_note'] = 'The Page Style Name of the custom payment page theme you created in PayPal. Leave blank for the default page style.';
$lang['PaypalPaymentsStandard.dev_mode'] = 'Developer Mode';
$lang['PaypalPaymentsStandard.dev_mode_note'] = 'Enabling this option will post transactions to the PayPal Sandbox environment. Only enable this option if you are testing with a PayPal Sandbox account.';
$lang['PaypalPaymentsStandard.api_username'] = 'API Username';
$lang['PaypalPaymentsStandard.api_username_note'] = 'This, as well as API Password and API Signature, are required in order to process refunds through PayPal.';
$lang['PaypalPaymentsStandard.api_password'] = 'API Password';
$lang['PaypalPaymentsStandard.api_signature'] = 'API Signature';
$lang['PaypalPaymentsStandard.pay_type'] = 'Payment Options';
$lang['PaypalPaymentsStandard.pay_type_onetime'] = 'One time payments only';
$lang['PaypalPaymentsStandard.pay_type_subscribe'] = 'Subscription payments only';
$lang['PaypalPaymentsStandard.pay_type_both'] = 'One time and subscription payments when possible';
$lang['PaypalPaymentsStandard.payment_mapping'] = 'Payment Mapping';
$lang['PaypalPaymentsStandard.payment_mapping_note'] = 'Intended for use with PayPal Subscriptions that were created outside of Blesta. Map payer_email to internal Client ID, 1 per line. For example: email,client-id';

$lang['PaypalPaymentsStandard.buildprocess.submit'] = 'Pay with PayPal';

// Errors
$lang['PaypalPaymentsStandard.!error.account_id.valid'] = 'You must enter a valid email address.';
$lang['PaypalPaymentsStandard.!error.dev_mode.valid'] = 'Developer mode must be set to "true" if given.';
$lang['PaypalPaymentsStandard.!error.payment_mapping.valid'] = 'An invalid line was found in your mapping data, check if the email address and Client ID is valid and try again.';
$lang['PaypalPaymentsStandard.!error.payment_mapping.duplicated'] = 'Duplicate emails were found in your mapping data, remove duplicates and try again.';
